@@ -12,7 +12,9 @@ pub fn hash(buffer: &[u8]) -> String {
 pub mod osrs {
     use osrscache::Cache;
 
-    use osrscache::loader::osrs::{ItemLoader, NpcLoader, ObjectLoader};
+    use osrscache::loader::osrs::{
+        InventoryLoader, ItemLoader, NpcLoader, ObjectLoader, VarbitLoader,
+    };
     pub fn setup() -> osrscache::Result<Cache> {
         Cache::new("./data/osrs_cache")
     }
@@ -27,4 +29,12 @@ pub mod osrs {
     pub fn load_objects(cache: &Cache) -> osrscache::Result<ObjectLoader> {
         ObjectLoader::new(cache)
     }
+
+    pub fn load_inventories(cache: &Cache) -> osrscache::Result<InventoryLoader> {
+        InventoryLoader::new(cache)
+    }
+
+    pub fn load_varbits(cache: &Cache) -> osrscache::Result<VarbitLoader> {
+        VarbitLoader::new(cache)
+    }
 }
